[freenet-cvs] r11281 - trunk/freenet/src/freenet/io/comm

toad at freenetproject.org toad at freenetproject.org
Thu Dec 7 15:46:42 UTC 2006


Author: toad
Date: 2006-12-07 15:46:42 +0000 (Thu, 07 Dec 2006)
New Revision: 11281

Modified:
   trunk/freenet/src/freenet/io/comm/UdpSocketManager.java
Log:
Assume a 1400 byte MTU. Apparently AOL has one. :(

Modified: trunk/freenet/src/freenet/io/comm/UdpSocketManager.java
===================================================================
--- trunk/freenet/src/freenet/io/comm/UdpSocketManager.java	2006-12-07 14:58:48 UTC (rev 11280)
+++ trunk/freenet/src/freenet/io/comm/UdpSocketManager.java	2006-12-07 15:46:42 UTC (rev 11281)
@@ -673,9 +673,10 @@
      * @return The maximum packet size supported by this SocketManager.
      */
     public int getMaxPacketSize() {
-    	return 1472-28; // officially GRE is 1476 and PPPoE is 1492.
-    	// unofficially, PPPoE is often 1472 (seen in the wild). Also PPPoATM is sometimes 1472. 
-    	// So use that. Minus 28 bytes for UDP/IP header.
+    	return 1400-28; // AOL and CompuServe use 1400 MTU
+    	// officially GRE is 1476 and PPPoE is 1492.
+    	// unofficially, PPPoE is often 1472 (seen in the wild). Also PPPoATM is sometimes 1472.
+    	// UDP/IP header is 28 bytes.
     }
 
 	/**




More information about the cvs mailing list